@@ -1975,6 +1975,9 @@ void split(char *fname, char *varlist, char *classvalvars)
   dap_free(varname, "");
 }
 
+
+
+
 void join(char *fname, char *partvars, char *valuevar)
 {
   char *partvars1;	/* all of partvars except last variable */
@@ -2660,3 +2663,125 @@ static void dsort(char *origset, char *sortset, int sortvar[], int nsort,
   dap_free(keyend, "");
   dap_free(keymap, "");
 }
+
+int* bubblesort(int * list,int n, int order){    
+  int *returndata=(int *) dap_malloc(n * sizeof(int), "return");
+    //copy table
+    int i = 0;
+    for (i = 0 ;i<n;i++)
+    {
+      returndata[i]=list[i];
+    }
+    int swappedcount=0;
+    int swapped = 0;
+    do {
+      swapped = 0;
+     
+     i = 1;
+     for (i = 1 ;i<n;i++)
+     {
+       if (order>0)
+       {
+	if (returndata[i-1]>returndata[i])
+	{
+	  int act=returndata[i];
+	  returndata[i]=returndata[i-1];
+	  returndata[i-1]=act;
+	  swapped = 1;
+	  swappedcount++;
+	}
+       }
+       else
+       {
+	if (returndata[i-1]<returndata[i])
+	{
+	  int act=returndata[i];
+	  returndata[i]=returndata[i-1];
+	  returndata[i-1]=act;
+	  swapped = 1;
+	  swappedcount++;
+	}
+       }
+     }
+     }while(swapped);
+     printf("nb swapped =%d\n",swappedcount);
+     return returndata;
+}
+
+void surveyselect(char *fname,char *outname,char *method,int tirage)
+{
+  inset(fname);	/* set up input dataset */
+  //counting nb line
+  int nbLines=0;
+  while (step())
+  {
+    nbLines++;
+  }
+  printf("nblines to read = %d, nb selected = %d\n",nbLines,tirage);
+  
+  int *list=(int *) dap_malloc(tirage * sizeof(int), "list");
+  
+  int i=0;
+  
+  int sysrand=rand()%(nbLines/tirage);
+  printf("reload data\n");
+  
+  printf("create index list based on method\n");
+  for (i=0;i<tirage;i++)
+  {
+    if (strcmp(method,"SRS")==0)
+    {
+      int notalone=0;
+      int choice=0;
+      do{
+	choice=rand()%nbLines;
+	int j=0;
+	notalone=0;
+	for(j=0;j<i;j++)
+	  if(list[j]==choice)
+	    notalone=1;
+      }while(notalone==1);
+      list[i]=choice;
+    }else
+    if (strcmp(method,"SYS")==0)
+    {
+      if (i==0)
+      {
+	list[i]=sysrand;
+      }
+      else
+      {
+	list[i]=list[i-1]+nbLines/tirage;
+	
+      }
+      
+    }
+    
+  }
+  printf("sort values\n");
+  int *listsorted=bubblesort(list,tirage,1);
+  int counter=0;
+  int index=0;
+  printf("set output\n");
+  inset(fname);	/* set up input dataset */
+  outset(outname, ""); /* set up output dataset */
+  while (step())
+  {
+      int founded=0;
+      for(i=0;i<tirage;i++)
+      {
+	  if(listsorted[i]==counter)
+	    founded=1;
+      }
+      if (founded)
+      {
+
+	output();	/* and write line to output dataset */
+	index++;
+      }
+      counter++;
+  }
+  dap_free(list, "");
+  dap_free(listsorted, "");
+
+}
\ No newline at end of file
