@@ -1266,6 +1266,8 @@ void proctrans(char *step, FILE *dapfile)
     daptrans(step + 9, dapfile);
    else if (!linecmp(step + 5, "import"))
     importtrans(step + 9, dapfile);
+   else if (!linecmp(step + 5, "surveyselect"))
+    surveyselecttrans(step + 9, dapfile);
   else
     {
       for (s = 5; step[s] && step[s] != '\n'; s++)
