@@ -736,4 +736,38 @@ void importtrans(char *step, FILE *dapfile)
   /* we have to sort by the class vars and to get means, etc. */
   fprintf(dapfile, "import(\"%s\", %s , \"%s\",%s, %i,%i);\n", setname,datafile,dbms,delimiter,replace,getnam);
   
+}
+
+
+/* import call to DAP. step starts after "proc import" */
+void surveyselecttrans(char *step, FILE *dapfile)
+{
+  int s; /* index to step */
+  int brace; /* level of braces nesting */
+  int start; /* starting position */
+  int resplen; /* length of response variable name */
+  int replace=0;
+  static char nbtirage[TOKENLEN + 1];
+  static char setname[TOKENLEN + 1];
+  static char datafile[TOKENLEN + 1];
+  static char method[TOKENLEN + 1];
+  static char strreplace[TOKENLEN + 1];
+  static char getnames[4];
+	//data =tPres2007 method=SRS  n = 220  reps= 50  seed= 1213   out=sasPres2007 stats
+  if (!getoption(step, "out", setname, 1))
+    strcpy(setname, sbstmp);
+  if (!getoption(step, "data", datafile, 1))
+    strcpy(datafile, sbstmp);
+  if (!getoption(step, "method", method, 1))
+    strcpy(method, sbstmp);
+  if (!getoption(step, "n", nbtirage, 1))
+    strcpy(nbtirage, "1");
+ 
+
+   
+  
+  /* we have to sort by the class vars and to get means, etc. */
+  // surveyselect(char *fname,char *outname,char *method,int tirage);
+  fprintf(dapfile, " surveyselect(\"%s\", \"%s\" , \"%s\",%s);\n", datafile,setname,method,nbtirage);
+  
 }
\ No newline at end of file
